package cn.wise.sc.consume.business.entity.cmbnoenet.model;



import java.io.Serializable;
import java.util.List;

/**
 * @description: 响应封装
 * @author: qh
 * @create: 2019-12-12 15:04
 **/
public class BaseResponse<T> implements Serializable {

    private static final long serialVersionUID = 2739858008722562194L;

    public String msg;

    public int code;

    public T data;

    public String className;

    public String getMsg() {
        return msg;
    }

    public void setMsg(String msg) {
        this.msg = msg;
    }

    public int getCode() {
        return code;
    }

    public void setCode(int code) {
        this.code = code;
    }

    public T getData() {
        return data;
    }

    public void setData(T data) {
        this.data = data;
    }

    public String getClassName() {
        return className;
    }

    public void setClassName(String className) {
        this.className = className;
    }



    private static <T> BaseResponse<T> createBaseResponse(T t) {
        return new BaseResponse<T>();
    }

    public static <T> BaseResponse<T> ok() {
        BaseResponse<T> baseResponse = new BaseResponse<>();
        baseResponse.setCode(200);
        baseResponse.setMsg("操作成功");
        return baseResponse;
    }

    public static <T> BaseResponse<T> ok(T data) {

        BaseResponse<T> baseResponse = createBaseResponse(data);

        baseResponse.setCode(200);

        baseResponse.setData(data);

        baseResponse.setClassName(data.getClass().getName());

        baseResponse.setMsg("操作成功");

        return baseResponse;
    }

    public static <T> BaseResponse<T> ok(T data, Class clazz) {

        BaseResponse<T> baseResponse = createBaseResponse(data);

        baseResponse.setCode(200);

        baseResponse.setData(data);

        baseResponse.setClassName(clazz.getName());

        baseResponse.setMsg("操作成功");

        return baseResponse;
    }

    public static <T> BaseResponse<T> okMsg(String msg, Class clazz) {

        BaseResponse<T> baseResponse = createBaseResponse(null);

        baseResponse.setCode(200);

        baseResponse.setData(null);

        baseResponse.setClassName(clazz.getName());

        baseResponse.setMsg(msg);

        return baseResponse;
    }

    public static <T> BaseResponse<T> ok(List<T> list, Class clazz) {

        BaseResponse<T> baseResponse = createBaseResponse(null);

        baseResponse.setCode(200);

        baseResponse.setData(null);

        baseResponse.setClassName(clazz.getName());

        baseResponse.setMsg("操作成功");

        return baseResponse;
    }

    public static <T> BaseResponse<T> ok(String msg, T data) {

        BaseResponse<T> baseResponse = createBaseResponse(data);

        baseResponse.setCode(200);

        baseResponse.setData(data);

        baseResponse.setClassName(data.getClass().getName());

        baseResponse.setMsg(msg);

        return baseResponse;
    }


    public static <T> BaseResponse<T> error(String msg, T data) {

        BaseResponse<T> baseResponse = createBaseResponse(data);

        baseResponse.setCode(400);

        baseResponse.setData(data);

        baseResponse.setClassName(data.getClass().getName());

        baseResponse.setMsg(msg);

        return baseResponse;
    }

    public static <T> BaseResponse<T> error(String msg, String clazz) {

        BaseResponse<T> baseResponse = createBaseResponse(null);

        baseResponse.setCode(400);

        baseResponse.setData(null);

        baseResponse.setClassName(clazz);

        baseResponse.setMsg(msg);

        return baseResponse;
    }

    public static BaseResponse<String> hystrixError(String author) {

        BaseResponse<String> baseResponse = createBaseResponse(null);
        baseResponse.setCode(666666);
        baseResponse.setData(null);
        baseResponse.setClassName("熔断器");
        baseResponse.setMsg("它又触发熔断了! 太难了! /(ㄒoㄒ)/~~  问问是不是在调试 ___*( ￣皿￣)/#____" + "author:" + author);
        return baseResponse;
    }
}
